@@ -4,6 +4,6 @@ if (requireNamespace("tinytest", quietly = TRUE) &&
     ## Set a seed to make the test deterministic
     set.seed(808)
 
-    tinytest::test_package("reda", ncpu = getOption("Ncpus", 1),
+    tinytest::test_package("reda", ncpu = NULL,
                            side_effects = TRUE)
 }
